/*eslint no-var: "error" */
/*eslint no-unused-vars: "off" */
/*eslint linebreak-style: "off" */
/*eslint no-trailing-spaces: "off" */
/*eslint-env es6*/
// Put this file in path/to/plugin/amd/src
// You can call it anything you like


import {call} from 'core/ajax';
import notification from 'core/notification';
import Vue from 'local_treestudyplan/vue';
import RVComponents from 'local_treestudyplan/report-viewer-components';
import TSComponents from 'local_treestudyplan/treestudyplan-components';
import Debugger from 'local_treestudyplan/debugger';

import {load_strings} from 'local_treestudyplan/string-helper';
import {ProcessStudyplans, fixLineWrappers} from 'local_treestudyplan/studyplan-processor';

import PortalVue from 'local_treestudyplan/portal-vue';
import BootstrapVue from 'local_treestudyplan/bootstrap-vue';
Vue.use(TSComponents);
Vue.use(RVComponents);
Vue.use(PortalVue);
Vue.use(BootstrapVue);


let debug = new Debugger("mytreestudyplan");
debug.enable();

let strings = load_strings({
    studyplan: {
        
    },
});

/**
 * Initialize the Page
 */
/**
 * Initialize the Page
 * @param {string} type Type of page to show
 * @param {Object} arg Arguments passed
 */
 export function init(type="myreport",arg) {
    // Make sure on window resize, the line wrappers are repositioned, to fix scrolling issues
    window.addEventListener('resize',fixLineWrappers); 
    let app = new Vue({
        el: '#block_mytreestudyplan',
        data: {
            "studyplans": [],
        },
        mounted() {
            let call_method;
            let call_args;
            if(type == "teacher"){
                call_method = 'local_treestudyplan_get_teacher_studyplan';
                call_args = {};
            }
            else if(type == "teaching"){
                call_method = 'local_treestudyplan_get_teaching_studyplans';
                call_args = {};
            }
            else{
                call_method = 'local_treestudyplan_get_own_studyplan';
                call_args = {};
            }
            call([{
                methodname: call_method,
                args: call_args
            }])[0].done(function(response){
                debug.info("Studyplans:",response);
                const timingval = { future: 0, present: 1, past: 2, };
                response.sort((a,b) => {
                    const timinga = TSComponents.studyplanTiming(a);
                    const timingb = TSComponents.studyplanTiming(b);

                    let t = timingval[timinga] - timingval[timingb];
                    if(t == 0){
                        // sort by start date if timing is equal
                        t = new Date(b.startdate).getTime() - new Date(a.startdate).getTime();
                        
                        if (t == 0) {
                            // sort by name if timing is equal
                            t = a.name.localeCompare(b.name);
                        }
                    }
                    return t;
                });
                app.studyplans = ProcessStudyplans(response);
            }).fail(notification.exception);            
        
        },
        created() {
            this.$root.$on('redrawLines',()=>{
                // Ugly hack, but currently the only way to properly fix scrollablility in the lines
                fixLineWrappers();
            });
        },        
        updated() {
            // Ugly hack, but currently the only way to properly fix scrollablility in the lines
            setTimeout(fixLineWrappers, 50);
        },
        methods: {
           
        },
    });

}


